@@ -15,25 +15,28 @@ sub make_iterator {
     my($class, $src) = @_;
 
     my $path = $src->meta->{file}{dir} . $src->meta->{file}{basename};
+    my @inc = map { s/^-I//; $_ } grep { /^-I/ } @{ $src->switches };
 
     pipe my $reader, my $writer;
     my $pid = fork;
     if ($pid) {
+        close $writer;
         return App::ForkProve::PipeIterator->new($reader, $pid);
     } else {
+        close $reader;
         open STDOUT, ">&", $writer;
-        open STDERR, ">&", $writer;
-        _run($path);
+        _run($path, \@inc);
         exit;
     }
 }
 
 sub _run {
-    my $t = shift;
+    my ($t, $inc) = @_;
 
     # Many tests especially Exception tests rely on test file name being
     # passed as t/foo.t without a leading path
     local $0 = $t;
+    local @INC = (@$inc, @INC);
     _setup();
     eval qq{ package main; do \$t; 1 } or die $!;
     _teardown();
@@ -49,6 +52,7 @@ sub _setup {
 sub _teardown {
     # Tests with no_plan rely on END to call done_testing
     if (defined $Test::Builder::Test) {
+        local $?; # since we aren't in an END block, this isn't relevant
         $Test::Builder::Test->_ending;
     }
 }
